==> 1.3.1.zip: bentobox/.github/ISSUE_TEMPLATE/bug_report.md <==
---
name: Bug report
about: Report a bug or a problem you're encountering with BentoBox.
title: ''
labels: 'Priority: Medium, Status: Pending, Type: Bug'
assignees: ''

---

### Description
#### Describe the bug
<!-- A clear and concise description of the problem you're encountering. -->
<!-- /!\ Leaving this section blank will result in your ticket being closed without further explanation. -->
<!-- Please type below this line. -->

#### Steps to reproduce the behavior
<!-- Step-by-step instructions for us to reproduce the bug on our side. -->
<!-- /!\ Leaving this section blank will result in your ticket being closed without further explanation. -->
<!-- Please type below this line. -->

#### Screenshots and videos
<!-- Videos and screenshots are helpful as they can provide better ingormation about your problem. -->
<!-- Please type below this line. -->

#### Expected behavior
<!-- Clear and concise description of what you actually expected to happen when you encountered this bug. -->
<!-- Please type below this line. -->

### Environment

#### Server
<!-- /!\ Leaving this section blank will result in your ticket being closed without further explanation. -->
<!-- Please replace the underscores with your answer. Do not remove the '*' characters. -->
 - OS: **________**
 - Java version: **________**

#### Plugins
<!-- /!\ Leaving this section blank will result in your ticket being closed without further explanation. -->
<!-- Please paste the `/plugins` output inside the code block below (remove the underscores). Do not provide an image. -->
```
_______
```

#### BentoBox setup

##### BentoBox and Addons
<!-- /!\ Leaving this section blank will result in your ticket being closed without further explanation. -->
<!-- Please paste the output of `/bentobox version` in the code block below (replace the underscores). Do not provide an image. -->
```
_______
```

##### Configuration
<!-- /!\ Leaving this section blank will result in your ticket being closed without further explanation. -->
<!-- Please replace the underscores with your answer. Do not remove the '*' characters. -->
 - Database: **________** <!-- Available options: YAML, JSON, MYSQL, MARIADB, MONGODB -->

### Additional context
<!-- Any additional information you'd like to provide us. -->
<!-- Please type below this line. -->

==> 1.5.1.zip: bentobox/.github/ISSUE_TEMPLATE/bug_report.md <==
---
name: Bug report
about: Report a bug or a problem you're encountering with BentoBox.
title: ''
labels: 'Status: Pending, Type: Bug'
assignees: ''

---

### Description
#### Describe the bug
<!-- A clear and concise description of the problem you're encountering. -->
<!-- /!\ Leaving this section blank will result in your ticket being closed without further explanation. -->
<!-- Please type below this line. -->

#### Steps to reproduce the behavior
<!-- Step-by-step instructions for us to reproduce the bug on our side. -->
<!-- /!\ Leaving this section blank will result in your ticket being closed without further explanation. -->
<!-- Please type below this line. -->

#### Screenshots and videos
<!-- Videos and screenshots are helpful as they can provide better information about your problem. -->
<!-- Please type below this line. -->

#### Expected behavior
<!-- Clear and concise description of what you actually expected to happen when you encountered this bug. -->
<!-- Please type below this line. -->

### Environment

#### Server
<!-- /!\ Leaving this section blank will result in your ticket being closed without further explanation. -->
<!-- Please replace the underscores with your answer. Do not remove the '*' characters. -->
 - OS: **________**
 - Java version: **________**

#### Plugins
<!-- /!\ Leaving this section blank will result in your ticket being closed without further explanation. -->
<!-- Please paste the `/plugins` output inside the code block below (remove the underscores). Do not provide an image. -->
```
_______
```

#### BentoBox setup

##### BentoBox and Addons
<!-- /!\ Leaving this section blank will result in your ticket being closed without further explanation. -->
<!-- Please paste the output of `/bentobox version` in the code block below (replace the underscores). Do not provide an image. -->
```
_______
```

##### Configuration
<!-- /!\ Leaving this section blank will result in your ticket being closed without further explanation. -->
<!-- Please replace the underscores with your answer. Do not remove the '*' characters. -->
 - Database: **________** <!-- Available options: YAML, JSON, MYSQL, MARIADB, MONGODB -->

### Additional context
<!-- Any additional information you'd like to provide us. -->
<!-- Please type below this line. -->
